@@ -8,16 +8,16 @@ function (aa) {
            "A","C","D","E","F","G",
            "H","I","K","L","M","N","P","Q",
            "R","S","T","V","W","Y",
-           "S","T","K","M","D","C","C","C","C","C","C",
+           "S","T","K","M","D","C","C","C","C","C","C","C",
            "H","H","H","H","H","H","H",
-           "M")
+           "M", "D")
   aa3 <- c("---", "---","UNK",
            "ALA", "CYS", "ASP", "GLU", "PHE", "GLY",
            "HIS", "ILE", "LYS", "LEU", "MET", "ASN", "PRO", "GLN",
            "ARG", "SER", "THR", "VAL", "TRP", "TYR",
-           "SEP", "TPO", "MLY", "MSE", "IAS", "ABA","CSO","CSD","CYM","CME","CSX",
+           "SEP", "TPO", "MLY", "MSE", "IAS", "ABA","CSO","CSD","CYM","CME","CSX","CMT",
            "HIE", "HIP", "HID", "HSD", "HSE", "HSP","DDE",
-           "MHO")
+           "MHO", "ASX")
     convert <- function(x) {
       if(is.na(x)) return(NA)
       if (all(x != aa3)) {
