@@ -150,7 +150,8 @@ function(trjfile, big=FALSE, verbose=TRUE){
 
   
     if (verbose) {
-      cat( sub(" +$","",gsub(pattern="\0", replacement="", x=title)),sep="\n" )
+## EDIT ## R version 2.11.0 does not like "\0", just remove for now - Apr 12 2010   
+##      cat( sub(" +$","",gsub(pattern="\0", replacement="", x=title)),sep="\n" )
       cat(" NATOM =",natom,"\n")
       cat(" NFRAME=",nframe,"\n")
       cat(" ISTART=",first,"\n")
