@@ -27,7 +27,7 @@ function(aln, id=NULL,
   if(refine) extra.args <- paste(extra.args,"-refine")
   if(protein) {
     extra.args <- paste(extra.args,"-seqtype protein")
-  } else { extra.args <- paste(extra.args,"-seqtype nucleo") }
+  } else { extra.args <- paste(extra.args,"-seqtype dna") }
   
   cmd <- paste(exepath, "muscle -in ",toaln," -out ",file, " ",extra.args, sep="")
   cat(cmd)
